==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/HTTPDateFormat.h <==
// public class gnu.java.net.protocol.http.HTTPDateFormat

// class file dependencies
// @dep_class 57ce926073440dd7 gnu_java_net_protocol_http_HTTPDateFormat
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 28a5c14be2925e18 java_text_DateFormat
// @dep_class f7ea2a00f35f8ce8 java_text_Format

// header file dependencies
// @dep_header java_text_DateFormat

#include "java/text/DateFormat.h"

#ifndef _JC_gnu_java_net_protocol_http_HTTPDateFormat_H_
#define _JC_gnu_java_net_protocol_http_HTTPDateFormat_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_text_FieldPosition$object;
struct _jc_java_text_NumberFormat$object;
struct _jc_java_text_ParsePosition$object;
struct _jc_java_util_Calendar$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$refs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object	_jc_gnu_java_net_protocol_http_HTTPDateFormat$object;

typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct	_jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct {
	_jc_object_array	*DAYS__5fOF__5fWEEK;
	_jc_object_array	*MONTHS;
};
extern _jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *);

// Virtual methods
extern struct _jc_java_lang_StringBuffer$object *_jc_gnu_java_net_protocol_http_HTTPDateFormat$method$format$7a8b22a81c050316(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Date$object *, struct _jc_java_lang_StringBuffer$object *, struct _jc_java_text_FieldPosition$object *);
extern struct _jc_java_util_Date$object *_jc_gnu_java_net_protocol_http_HTTPDateFormat$method$parse$a04056e0f8a18ae2(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, struct _jc_java_text_ParsePosition$object *);
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$setCalendar$50ded889a3879905(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Calendar$object *);
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$setNumberFormat$3f08209e7f2cedd7(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_text_NumberFormat$object *);
extern jint _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$skipNonWhitespace$de0932a72fd21423(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint);
extern jint _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$skipTo$ffe73749f51b8ee5(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint, jchar);
extern jint _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$skipWhitespace$b787ec5b72f400b8(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$format$7a8b22a81c050316;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$parse$a04056e0f8a18ae2;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$setCalendar$50ded889a3879905;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$setNumberFormat$3f08209e7f2cedd7;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$skipNonWhitespace$de0932a72fd21423;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$skipTo$ffe73749f51b8ee5;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$skipWhitespace$b787ec5b72f400b8;

// Static methods
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods {
	struct _jc_java_lang_StringBuffer$object	*(*format$7a8b22a81c050316)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Date$object *, struct _jc_java_lang_StringBuffer$object *, struct _jc_java_text_FieldPosition$object *);
	struct _jc_java_util_Date$object	*(*parse$a04056e0f8a18ae2)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, struct _jc_java_text_ParsePosition$object *);
	void	(*setCalendar$50ded889a3879905)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Calendar$object *);
	void	(*setNumberFormat$3f08209e7f2cedd7)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_text_NumberFormat$object *);
	jint	(*skipNonWhitespace$de0932a72fd21423)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint);
	jint	(*skipTo$ffe73749f51b8ee5)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint, jchar);
	jint	(*skipWhitespace$b787ec5b72f400b8)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_Format$vmethods	java_text_Format;
	_jc_java_text_DateFormat$vmethods	java_text_DateFormat;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods	gnu_java_net_protocol_http_HTTPDateFormat;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$refs {
    _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs	gnu_java_net_protocol_http_HTTPDateFormat;
    _jc_java_text_DateFormat$sub_refs	java_text_DateFormat;
    _jc_java_text_Format$sub_refs	java_text_Format;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_Format$sub_nonrefs	java_text_Format;
    _jc_java_text_DateFormat$sub_nonrefs	java_text_DateFormat;
    _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs	gnu_java_net_protocol_http_HTTPDateFormat;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object {
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype _jc_gnu_java_net_protocol_http_HTTPDateFormat$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_HTTPDateFormat, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_HTTPDateFormat$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_HTTPDateFormat_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/HTTPDateFormat.h <==
// public class gnu.java.net.protocol.http.HTTPDateFormat

// class file dependencies
// @dep_class 57ce926073440dd7 gnu_java_net_protocol_http_HTTPDateFormat
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 28a5c14be2925e18 java_text_DateFormat
// @dep_class f7ea2a00f35f8ce8 java_text_Format

// header file dependencies
// @dep_header java_text_DateFormat

#include "java/text/DateFormat.h"

#ifndef _JC_gnu_java_net_protocol_http_HTTPDateFormat_H_
#define _JC_gnu_java_net_protocol_http_HTTPDateFormat_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_text_FieldPosition$object;
struct _jc_java_text_NumberFormat$object;
struct _jc_java_text_ParsePosition$object;
struct _jc_java_util_Calendar$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$refs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs	_jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object	_jc_gnu_java_net_protocol_http_HTTPDateFormat$object;

typedef struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct	_jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct {
	_jc_object_array	*DAYS__5fOF__5fWEEK;
	_jc_object_array	*MONTHS;
};
extern _jc_gnu_java_net_protocol_http_HTTPDateFormat$fields_struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_StringBuffer$object *_jc_gnu_java_net_protocol_http_HTTPDateFormat$method$format$7a8b22a81c050316(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Date$object *, struct _jc_java_lang_StringBuffer$object *, struct _jc_java_text_FieldPosition$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Date$object *_jc_gnu_java_net_protocol_http_HTTPDateFormat$method$parse$a04056e0f8a18ae2(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$setCalendar$50ded889a3879905(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Calendar$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$setNumberFormat$3f08209e7f2cedd7(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_text_NumberFormat$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$skipNonWhitespace$de0932a72fd21423(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$skipTo$ffe73749f51b8ee5(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint, jchar) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$skipWhitespace$b787ec5b72f400b8(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$format$7a8b22a81c050316;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$parse$a04056e0f8a18ae2;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$setCalendar$50ded889a3879905;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$setNumberFormat$3f08209e7f2cedd7;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$skipNonWhitespace$de0932a72fd21423;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$skipTo$ffe73749f51b8ee5;
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPDateFormat$method_info$skipWhitespace$b787ec5b72f400b8;

// Static methods
extern void _jc_gnu_java_net_protocol_http_HTTPDateFormat$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods {
	struct _jc_java_lang_StringBuffer$object	*(*format$7a8b22a81c050316)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Date$object *, struct _jc_java_lang_StringBuffer$object *, struct _jc_java_text_FieldPosition$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Date$object	*(*parse$a04056e0f8a18ae2)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;
	void	(*setCalendar$50ded889a3879905)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_util_Calendar$object *) _JC_JCNI_ATTR;
	void	(*setNumberFormat$3f08209e7f2cedd7)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_text_NumberFormat$object *) _JC_JCNI_ATTR;
	jint	(*skipNonWhitespace$de0932a72fd21423)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	jint	(*skipTo$ffe73749f51b8ee5)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint, jchar) _JC_JCNI_ATTR;
	jint	(*skipWhitespace$b787ec5b72f400b8)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_Format$vmethods	java_text_Format;
	_jc_java_text_DateFormat$vmethods	java_text_DateFormat;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vmethods	gnu_java_net_protocol_http_HTTPDateFormat;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$refs {
    _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_refs	gnu_java_net_protocol_http_HTTPDateFormat;
    _jc_java_text_DateFormat$sub_refs	java_text_DateFormat;
    _jc_java_text_Format$sub_refs	java_text_Format;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_Format$sub_nonrefs	java_text_Format;
    _jc_java_text_DateFormat$sub_nonrefs	java_text_DateFormat;
    _jc_gnu_java_net_protocol_http_HTTPDateFormat$sub_nonrefs	gnu_java_net_protocol_http_HTTPDateFormat;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_HTTPDateFormat$object {
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_HTTPDateFormat$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_HTTPDateFormat$vtype _jc_gnu_java_net_protocol_http_HTTPDateFormat$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_HTTPDateFormat, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_HTTPDateFormat$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_HTTPDateFormat_H_ */
